==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/webpubsub/kotlin/inputs/LiveTraceConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.webpubsub.kotlin.inputs

import com.pulumi.azurenative.webpubsub.inputs.LiveTraceConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Live trace configuration of a Microsoft.SignalRService resource.
 * @property categories Gets or sets the list of category configurations.
 * @property enabled Indicates whether or not enable live trace.
 * When it's set to true, live trace client can connect to the service.
 * Otherwise, live trace client can't connect to the service, so that you are unable to receive any log, no matter what you configure in "categories".
 * Available values: true, false.
 * Case insensitive.
 */
public data class LiveTraceConfigurationArgs(
    public val categories: Output<List<LiveTraceCategoryArgs>>? = null,
    public val enabled: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.webpubsub.inputs.LiveTraceConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.webpubsub.inputs.LiveTraceConfigurationArgs =
        com.pulumi.azurenative.webpubsub.inputs.LiveTraceConfigurationArgs.builder()
            .categories(
                categories?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .enabled(enabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LiveTraceConfigurationArgs].
 */
@PulumiTagMarker
public class LiveTraceConfigurationArgsBuilder internal constructor() {
    private var categories: Output<List<LiveTraceCategoryArgs>>? = null

    private var enabled: Output<String>? = null

    /**
     * @param value Gets or sets the list of category configurations.
     */
    @JvmName("xjxmrfsegmsuvsot")
    public suspend fun categories(`value`: Output<List<LiveTraceCategoryArgs>>) {
        this.categories = value
    }

    @JvmName("bythxaypmgduhfgm")
    public suspend fun categories(vararg values: Output<LiveTraceCategoryArgs>) {
        this.categories = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the list of category configurations.
     */
    @JvmName("hqpwvvfwmbjolajc")
    public suspend fun categories(values: List<Output<LiveTraceCategoryArgs>>) {
        this.categories = Output.all(values)
    }

    /**
     * @param value Indicates whether or not enable live trace.
     * When it's set to true, live trace client can connect to the service.
     * Otherwise, live trace client can't connect to the service, so that you are unable to receive any log, no matter what you configure in "categories".
     * Available values: true, false.
     * Case insensitive.
     */
    @JvmName("giqitcsoexkfemce")
    public suspend fun enabled(`value`: Output<String>) {
        this.enabled = value
    }

    /**
     * @param value Gets or sets the list of category configurations.
     */
    @JvmName("flcuitblshaangah")
    public suspend fun categories(`value`: List<LiveTraceCategoryArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.categories = mapped
    }

    /**
     * @param argument Gets or sets the list of category configurations.
     */
    @JvmName("eauvrtsritbwtmoe")
    public suspend fun categories(argument: List<suspend LiveTraceCategoryArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            LiveTraceCategoryArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.categories = mapped
    }

    /**
     * @param argument Gets or sets the list of category configurations.
     */
    @JvmName("cmakkkbgdjhwmohg")
    public suspend fun categories(vararg argument: suspend LiveTraceCategoryArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            LiveTraceCategoryArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.categories = mapped
    }

    /**
     * @param argument Gets or sets the list of category configurations.
     */
    @JvmName("cyaoaebklypjlpyu")
    public suspend fun categories(argument: suspend LiveTraceCategoryArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(LiveTraceCategoryArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.categories = mapped
    }

    /**
     * @param values Gets or sets the list of category configurations.
     */
    @JvmName("byebardybotxueav")
    public suspend fun categories(vararg values: LiveTraceCategoryArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.categories = mapped
    }

    /**
     * @param value Indicates whether or not enable live trace.
     * When it's set to true, live trace client can connect to the service.
     * Otherwise, live trace client can't connect to the service, so that you are unable to receive any log, no matter what you configure in "categories".
     * Available values: true, false.
     * Case insensitive.
     */
    @JvmName("wepjdwljkcsiyoxb")
    public suspend fun enabled(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    internal fun build(): LiveTraceConfigurationArgs = LiveTraceConfigurationArgs(
        categories = categories,
        enabled = enabled,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/webpubsub/kotlin/inputs/LiveTraceConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.webpubsub.kotlin.inputs

import com.pulumi.azurenative.webpubsub.inputs.LiveTraceConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Live trace configuration of a Microsoft.SignalRService resource.
 * @property categories Gets or sets the list of category configurations.
 * @property enabled Indicates whether or not enable live trace.
 * When it's set to true, live trace client can connect to the service.
 * Otherwise, live trace client can't connect to the service, so that you are unable to receive any log, no matter what you configure in "categories".
 * Available values: true, false.
 * Case insensitive.
 */
public data class LiveTraceConfigurationArgs(
    public val categories: Output<List<LiveTraceCategoryArgs>>? = null,
    public val enabled: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.webpubsub.inputs.LiveTraceConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.webpubsub.inputs.LiveTraceConfigurationArgs =
        com.pulumi.azurenative.webpubsub.inputs.LiveTraceConfigurationArgs.builder()
            .categories(
                categories?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .enabled(enabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LiveTraceConfigurationArgs].
 */
@PulumiTagMarker
public class LiveTraceConfigurationArgsBuilder internal constructor() {
    private var categories: Output<List<LiveTraceCategoryArgs>>? = null

    private var enabled: Output<String>? = null

    /**
     * @param value Gets or sets the list of category configurations.
     */
    @JvmName("pwcbioxfgmwokumf")
    public suspend fun categories(`value`: Output<List<LiveTraceCategoryArgs>>) {
        this.categories = value
    }

    @JvmName("hcvxjqnejonjirpo")
    public suspend fun categories(vararg values: Output<LiveTraceCategoryArgs>) {
        this.categories = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the list of category configurations.
     */
    @JvmName("ylaeiemptoyucmvl")
    public suspend fun categories(values: List<Output<LiveTraceCategoryArgs>>) {
        this.categories = Output.all(values)
    }

    /**
     * @param value Indicates whether or not enable live trace.
     * When it's set to true, live trace client can connect to the service.
     * Otherwise, live trace client can't connect to the service, so that you are unable to receive any log, no matter what you configure in "categories".
     * Available values: true, false.
     * Case insensitive.
     */
    @JvmName("hbogkbdluxvdjmke")
    public suspend fun enabled(`value`: Output<String>) {
        this.enabled = value
    }

    /**
     * @param value Gets or sets the list of category configurations.
     */
    @JvmName("liejgsagymrhveko")
    public suspend fun categories(`value`: List<LiveTraceCategoryArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.categories = mapped
    }

    /**
     * @param argument Gets or sets the list of category configurations.
     */
    @JvmName("dwjvmidoyucobyoh")
    public suspend fun categories(argument: List<suspend LiveTraceCategoryArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            LiveTraceCategoryArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.categories = mapped
    }

    /**
     * @param argument Gets or sets the list of category configurations.
     */
    @JvmName("rfxeogfndbkvpiwg")
    public suspend fun categories(vararg argument: suspend LiveTraceCategoryArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            LiveTraceCategoryArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.categories = mapped
    }

    /**
     * @param argument Gets or sets the list of category configurations.
     */
    @JvmName("tkpyevnyocdbhmie")
    public suspend fun categories(argument: suspend LiveTraceCategoryArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(LiveTraceCategoryArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.categories = mapped
    }

    /**
     * @param values Gets or sets the list of category configurations.
     */
    @JvmName("sxrgmvvedujotktg")
    public suspend fun categories(vararg values: LiveTraceCategoryArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.categories = mapped
    }

    /**
     * @param value Indicates whether or not enable live trace.
     * When it's set to true, live trace client can connect to the service.
     * Otherwise, live trace client can't connect to the service, so that you are unable to receive any log, no matter what you configure in "categories".
     * Available values: true, false.
     * Case insensitive.
     */
    @JvmName("pimjupsseiysnlvd")
    public suspend fun enabled(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    internal fun build(): LiveTraceConfigurationArgs = LiveTraceConfigurationArgs(
        categories = categories,
        enabled = enabled,
    )
}
